

#include <QMainWindow>
#include <QHash>

class QMaemo5ValueButton;
class QRadioButton;

class NewAlarm : public QMainWindow
{
Q_OBJECT

public:
	NewAlarm(QWidget *w = 0);

signals:
        void newAlarm();

public slots:
	void CreateAlarm();

private:
	QMaemo5ValueButton *m_vb;
	QRadioButton *m_rbnormal;
	QRadioButton *m_rbsilent; 
        QRadioButton *m_rboffline;
        QRadioButton *m_rbonline;
        QHash<QString,QRadioButton *> qhcb;

	
};

